pub enum InheritConfiguration {
All(bool),
Some(Vec<String>),
}Expand description
The set of configurations to inherit from the parent component.
Can be specified as:
true— inherit all configurationsfalse— inherit no configurations (equivalent to omitting the field)["key1", "key2"]— inherit only the specified configuration keys
Variants
All(bool)
All or no configurations will be inherited, specified as true or false.
Some(Vec<String>)
Only the specified configuration keys will be inherited from the parent component.