pub struct AppDetails {
pub name: String,
pub version: String,
pub description: String,
pub authors: Vec<String>,
pub targets: Vec<TargetEnvironmentRef>,
pub trigger_global_configs: IndexMap<String, Table>,
pub tool: IndexMap<String, Table>,
}Expand description
App details
Fields
name: StringThe name of the application.
Example: name = "my-app"
version: StringThe application version. This should be a valid semver version.
Example: version = "1.0.0"
description: StringA human-readable description of the application.
Example: description = "App description"
The author(s) of the application.
authors = ["author@example.com"]
targets: Vec<TargetEnvironmentRef>The Spin environments with which application components must be compatible unless otherwise specified. Individual components may express different requirements: these override the application-level default.
Example: targets = ["spin-up:3.3", "spinkube:0.4"]
trigger_global_configs: IndexMap<String, Table>Application-level settings for the trigger types used in the application. The possible values are trigger type-specific.
Example:
[application.triggers.redis]
address = "redis://notifications.example.com:6379"Learn more (Redis example): https://spinframework.dev/redis-trigger#setting-a-default-server
tool: IndexMap<String, Table>Settings for custom tools or plugins. Spin ignores this field.