pub struct AppManifest {
pub spin_manifest_version: FixedVersion<2>,
pub application: AppDetails,
pub variables: IndexMap<LowerSnakeId, Variable>,
pub triggers: IndexMap<String, Vec<Trigger>>,
pub components: IndexMap<KebabId, Component>,
}Expand description
App manifest
Fields
spin_manifest_version: FixedVersion<2>spin_manifest_version = 2
application: AppDetails[application]
variables: IndexMap<LowerSnakeId, Variable>Application configuration variables. These can be set via environment variables, or from sources such as Hashicorp Vault or Azure KeyVault by using a runtime config file. They are not available directly to components: use a component variable to ingest them.
Learn more: https://spinframework.dev/variables, https://spinframework.dev/dynamic-configuration#application-variables-runtime-configuration
triggers: IndexMap<String, Vec<Trigger>>The triggers to which the application responds. Most triggers can appear
multiple times with different parameters: for example, the http trigger may
appear multiple times with different routes, or the redis trigger with
different channels.
Example: [[trigger.http]]
components: IndexMap<KebabId, Component>[component.<id>]
Implementations
Sourceimpl AppManifest
impl AppManifest
Sourcepub fn validate_dependencies(&self) -> Result<()>
pub fn validate_dependencies(&self) -> Result<()>
This method ensures that the dependencies of each component are valid.
Sourcepub fn ensure_profile(&self, profile: Option<&str>) -> Result<()>
pub fn ensure_profile(&self, profile: Option<&str>) -> Result<()>
Whether any component in the application defines the given profile.
Not every component defines every profile, and components intentionally
fall back to the anonymouse profile if they are asked for a profile
they don’t define. So this can be used to detect that a user might have
mistyped a profile (e.g. spin up --profile deugb).